pdsf - A Python package for Pandas/Snowflake
========================================

The pdsf package contains convenience functions for adding, manipulating, and changing data in Snowflake servers with a emphasis on Pandas DataFrames for the handling of data in Python.

Installation
------------
pdsf can be installed via pip or conda::

  pip install pdsf

or::

  conda install -c mullenkamp pdsf

The core dependencies are Pandas, Sqlalchemy, and pyodbc.
